@@ -1,11 +1,8 @@
+import six
 
-from __future__ import with_statement
-
-import sys
-import util
-
-import tree
-from tokenizer import (
+from . import util
+from . import tree
+from .tokenizer import (
     EndOfInput, Keyword, Modifier, BasicType, Identifier,
     Annotation, Literal, Operator, JavaToken
     )
@@ -22,31 +19,31 @@ def parse_debug(method):
 
             if self.debug:
                 depth = "%02d" % (self.recursion_depth,)
-                token = unicode(self.tokens.look())
+                token = six.text_type(self.tokens.look())
                 start_value = self.tokens.look().value
                 name = method.__name__
                 sep = ("-" * self.recursion_depth)
                 e_message = ""
 
-                print "%s %s> %s(%s)" % (depth, sep, name, token)
+                print("%s %s> %s(%s)" % (depth, sep, name, token))
 
                 self.recursion_depth += 1
 
                 try:
                     r = method(self)
 
-                except JavaSyntaxError, e:
+                except JavaSyntaxError as e:
                     e_message = e.description
                     raise
 
-                except Exception, e:
-                    e_message = unicode(e)
+                except Exception as e:
+                    e_message = six.text_type(e)
                     raise
 
                 finally:
-                    token = unicode(self.tokens.last())
-                    print "%s <%s %s(%s, %s) %s" % \
-                        (depth, sep, name, start_value, token, e_message)
+                    token = six.text_type(self.tokens.last())
+                    print("%s <%s %s(%s, %s) %s" %
+                        (depth, sep, name, start_value, token, e_message))
                     self.recursion_depth -= 1
             else:
                 self.recursion_depth += 1
@@ -128,9 +125,9 @@ class Parser(object):
             raise JavaParserError("Missing acceptable values")
 
         for accept in accepts:
-            token = self.tokens.next()
-
-            if isinstance(accept, basestring) and not token.value == accept:
+            token = next(self.tokens)
+            if isinstance(accept, six.string_types) and (
+                    not token.value == accept):
                 self.illegal("Expected '%s'" % (accept,))
             elif isinstance(accept, type) and not isinstance(token, accept):
                 self.illegal("Expected %s" % (accept.__name__,))
@@ -146,7 +143,8 @@ class Parser(object):
         for i, accept in enumerate(accepts):
             token = self.tokens.look(i)
 
-            if isinstance(accept, basestring) and not token.value == accept:
+            if isinstance(accept, six.string_types) and (
+                    not token.value == accept):
                 return False
             elif isinstance(accept, type) and not isinstance(token, accept):
                 return False
@@ -160,13 +158,14 @@ class Parser(object):
         for i, accept in enumerate(accepts):
             token = self.tokens.look(i)
 
-            if isinstance(accept, basestring) and not token.value == accept:
+            if isinstance(accept, six.string_types) and (
+                    not token.value == accept):
                 return False
             elif isinstance(accept, type) and not isinstance(token, accept):
                 return False
 
         for i in range(0, len(accepts)):
-            self.tokens.next()
+            next(self.tokens)
 
         return True
 
@@ -180,7 +179,7 @@ class Parser(object):
         i = 0
 
         for level in range(start_level, len(self.operator_precedence)):
-            for j in xrange(1, len(parts) - 1, 2):
+            for j in range(1, len(parts) - 1, 2):
                 if parts[j] in self.operator_precedence[level]:
                     operand = self.build_binary_operation(parts[i:j], level + 1)
                     operator = parts[j]
@@ -505,8 +504,6 @@ class Parser(object):
         base_type = None
 
         if self.try_accept('?'):
-            wildcard = True
-
             if self.tokens.look().value in ('extends', 'super'):
                 pattern_type = self.tokens.next().value
             else:
@@ -804,6 +801,7 @@ class Parser(object):
         else:
             member = self.parse_method_or_field_declaraction()
 
+        member._position = token.position
         member.modifiers = modifiers
         member.annotations = annotations
         member.documentation = javadoc
@@ -911,7 +909,6 @@ class Parser(object):
             constructor_name = self.parse_identifier()
             method = self.parse_constructor_declarator_rest()
             method.name = constructor_name
-
         elif self.try_accept('void'):
             method_name = self.parse_identifier()
             method = self.parse_void_method_declarator_rest()
@@ -1074,7 +1071,6 @@ class Parser(object):
         type_parameters = self.parse_type_parameters()
         return_type = None
         method_name = None
-        rest = None
 
         if not self.try_accept('void'):
             return_type = self.parse_type()
@@ -1319,7 +1315,6 @@ class Parser(object):
     @parse_debug
     def parse_statement(self):
         token = self.tokens.look()
-
         if self.would_accept('{'):
             block = self.parse_block()
             return tree.BlockStatement(statements=block)
@@ -1497,8 +1492,6 @@ class Parser(object):
         self.accept('catch', '(')
 
         modifiers, annotations = self.parse_variable_modifiers()
-        catch_types = list()
-
         catch_parameter = tree.CatchClauseParameter(types=list())
 
         while True:
@@ -1721,12 +1714,10 @@ class Parser(object):
     @parse_debug
     def parse_expressionl(self):
         expression_2 = self.parse_expression_2()
-        is_ternary = False
         true_expression = None
         false_expression = None
 
         if self.try_accept('?'):
-            is_ternary = True
             true_expression = self.parse_expression()
             self.accept(':')
             false_expression = self.parse_expressionl()
@@ -1740,8 +1731,6 @@ class Parser(object):
     @parse_debug
     def parse_expression_2(self):
         expression_3 = self.parse_expression_3()
-        expression_2_rest = None
-
         token = self.tokens.look()
         if token.value in Operator.INFIX or token.value == 'instanceof':
             parts = self.parse_expression_2_rest()
@@ -1961,10 +1950,8 @@ class Parser(object):
 
     @parse_debug
     def parse_explicit_generic_invocation_suffix(self):
-        java_super = False
         identifier = None
         arguments = None
-
         if self.try_accept('super'):
             return self.parse_super_suffix()
         else:
@@ -2073,7 +2060,7 @@ class Parser(object):
             return tree.This()
 
         elif self.would_accept('.', '<'):
-            self.tokens.next()
+            next(self.tokens)
             return self.parse_explicit_generic_invocation()
 
         elif self.try_accept('.', 'new'):
